@@ -389,9 +389,7 @@ fn upgrade_req(
         log::debug!("unsupported dependency {}", name);
         return false;
     };
-    let existing_req = if let Ok(existing_req) = semver::VersionReq::parse(existing_req_str) {
-        existing_req
-    } else {
+    let Ok(existing_req) = semver::VersionReq::parse(existing_req_str) else {
         log::debug!("unsupported dependency req {}={}", name, existing_req_str);
         return false;
     };
@@ -461,11 +459,7 @@ pub fn sort_workspace(ws_meta: &cargo_metadata::Metadata) -> Vec<&cargo_metadata
                         .iter()
                         .all(|info| info.kind == cargo_metadata::DependencyKind::Development);
 
-                    if dev_only {
-                        None
-                    } else {
-                        Some(&dep.pkg)
-                    }
+                    if dev_only { None } else { Some(&dep.pkg) }
                 });
 
                 Some((&n.id, non_dev_pkgs.collect()))
